"use strict";
/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.getCurrentBenchmarkType = exports.describeE2EDocRun = exports.describeE2EDocsMemory = exports.describeE2EDocsRuntime = exports.describeE2EDocs = void 0;
const telemetry_utils_1 = require("@fluidframework/telemetry-utils");
const test_utils_1 = require("@fluidframework/test-utils");
const compatConfig_1 = require("./compatConfig");
const compatOptions_1 = require("./compatOptions");
const compatUtils_1 = require("./compatUtils");
function createE2EDocsDescribe(docTypes) {
    const d = (title, tests, testType) => {
        describe(`${testType} -`, createE2EDocCompatSuite(title, tests, docTypes));
    };
    return d;
}
function createE2EDocsDescribeWithType(testType, docTypes) {
    const d = (title, tests) => {
        describe(`${testType} -`, createE2EDocCompatSuite(title, tests, docTypes));
    };
    return d;
}
function createE2EDocCompatSuite(title, tests, docTypes) {
    const compatFilter = [compatOptions_1.CompatKind.None];
    let configs = compatConfig_1.configList.value;
    configs = configs.filter((value) => compatFilter.includes(value.kind));
    return function () {
        for (const config of configs) {
            for (const doctype of docTypes) {
                const name = `${title} - ${doctype.testTitle}`;
                describe(name, function () {
                    let provider;
                    let resetAfterEach;
                    before(async function () {
                        try {
                            provider = await (0, compatUtils_1.getVersionedTestObjectProvider)(compatOptions_1.baseVersion, config.loader, {
                                type: compatOptions_1.driver,
                                version: config.driver,
                                config: {
                                    r11s: { r11sEndpointName: compatOptions_1.r11sEndpointName },
                                    odsp: { tenantIndex: compatOptions_1.tenantIndex },
                                },
                            }, config.containerRuntime, config.dataRuntime);
                        }
                        catch (error) {
                            const logger = telemetry_utils_1.ChildLogger.create(getTestLogger === null || getTestLogger === void 0 ? void 0 : getTestLogger(), "DescribeE2EDocs");
                            logger.sendErrorEvent({
                                eventName: "TestObjectProviderLoadFailed",
                                driverType: compatOptions_1.driver,
                            }, error);
                            throw error;
                        }
                        Object.defineProperty(this, "__fluidTestProvider", { get: () => provider });
                    });
                    tests.bind(this)((options) => {
                        var _a;
                        resetAfterEach = (_a = options === null || options === void 0 ? void 0 : options.resetAfterEach) !== null && _a !== void 0 ? _a : true;
                        if ((options === null || options === void 0 ? void 0 : options.syncSummarizer) === true) {
                            provider.resetLoaderContainerTracker(true /* syncSummarizerClients */);
                        }
                        return provider;
                    }, () => {
                        return doctype;
                    });
                    afterEach(function (done) {
                        var _a;
                        // if the test failed for another reason
                        // then we don't need to check errors
                        // and fail the after each as well
                        if (((_a = this.currentTest) === null || _a === void 0 ? void 0 : _a.state) === "passed") {
                            const logErrors = (0, test_utils_1.getUnexpectedLogErrorException)(provider.logger);
                            done(logErrors);
                        }
                        else {
                            done();
                        }
                        if (resetAfterEach) {
                            provider.reset();
                        }
                    });
                });
            }
        }
    };
}
// Default document types to be used during the performance runs.
const E2EDefaultDocumentTypes = [
    {
        testTitle: "10Mb Map",
        documentType: "LargeDocumentMap",
    },
    {
        testTitle: "5Mb Map",
        documentType: "MediumDocumentMap",
    },
];
exports.describeE2EDocs = createE2EDocsDescribe(E2EDefaultDocumentTypes);
exports.describeE2EDocsRuntime = createE2EDocsDescribeWithType("Runtime benchmarks", E2EDefaultDocumentTypes);
exports.describeE2EDocsMemory = createE2EDocsDescribeWithType("Memory benchmarks", E2EDefaultDocumentTypes);
function createE2EDocsDescribeRun() {
    let isMemoryUsageTest = false;
    const childArgs = [...process.execArgv, ...process.argv.slice(1)];
    for (const flag of ["--grep", "--fgrep"]) {
        const flagIndex = childArgs.indexOf(flag);
        if (flagIndex > 0) {
            console.log("childArgs", childArgs[flagIndex + 1]);
            isMemoryUsageTest = childArgs[flagIndex + 1] === "@MemoryUsage" ? true : false;
            break;
        }
    }
    const isMemoryTest = process.env.FLUID_E2E_MEMORY !== undefined ? true : isMemoryUsageTest !== null && isMemoryUsageTest !== void 0 ? isMemoryUsageTest : false;
    console.log(`IsMemoryTest: ${isMemoryTest}`);
    return isMemoryTest === true ? exports.describeE2EDocsMemory : exports.describeE2EDocsRuntime;
}
exports.describeE2EDocRun = createE2EDocsDescribeRun();
const getCurrentBenchmarkType = (currentType) => {
    return currentType === exports.describeE2EDocsMemory ? "E2EMemory" : "E2ETime";
};
exports.getCurrentBenchmarkType = getCurrentBenchmarkType;
//# sourceMappingURL=describeE2eDocs.js.map