"use strict";
/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getDriverApi = exports.getDataRuntimeApi = exports.getContainerRuntimeApi = exports.getLoaderApi = exports.ensurePackageInstalled = void 0;
// Loader API
const container_loader_1 = require("@fluidframework/container-loader");
// Driver API
const test_drivers_1 = require("@fluidframework/test-drivers");
// ContainerRuntime API
const container_runtime_1 = require("@fluidframework/container-runtime");
// Data Runtime API
const cell_1 = require("@fluidframework/cell");
const counter_1 = require("@fluidframework/counter");
const ink_1 = require("@fluidframework/ink");
const map_1 = require("@fluidframework/map");
const matrix_1 = require("@fluidframework/matrix");
const ordered_collection_1 = require("@fluidframework/ordered-collection");
const register_collection_1 = require("@fluidframework/register-collection");
const sequence_1 = require("@fluidframework/sequence");
const test_utils_1 = require("@fluidframework/test-utils");
// ContainerRuntime and Data Runtime API
const aqueduct_1 = require("@fluidframework/aqueduct");
const sequence_deprecated_1 = require("@fluid-experimental/sequence-deprecated");
const semver = __importStar(require("semver"));
const packageVersion_1 = require("./packageVersion");
const versionUtils_1 = require("./versionUtils");
// List of package that needs to be install for legacy versions
const packageList = [
    "@fluidframework/aqueduct",
    "@fluidframework/test-utils",
    "@fluidframework/container-loader",
    "@fluidframework/container-runtime",
    "@fluidframework/cell",
    "@fluidframework/counter",
    "@fluidframework/ink",
    "@fluidframework/map",
    "@fluidframework/matrix",
    "@fluidframework/ordered-collection",
    "@fluidframework/register-collection",
    "@fluidframework/sequence",
    "@fluidframework/local-driver",
    "@fluidframework/odsp-driver",
    "@fluidframework/routerlicious-driver",
];
const ensurePackageInstalled = async (baseVersion, version, force) => (0, versionUtils_1.ensureInstalled)((0, versionUtils_1.getRequestedRange)(baseVersion, version), packageList, force);
exports.ensurePackageInstalled = ensurePackageInstalled;
// Current versions of the APIs
const LoaderApi = {
    version: packageVersion_1.pkgVersion,
    Loader: container_loader_1.Loader,
};
const ContainerRuntimeApi = {
    version: packageVersion_1.pkgVersion,
    ContainerRuntime: container_runtime_1.ContainerRuntime,
    ContainerRuntimeFactoryWithDefaultDataStore: aqueduct_1.ContainerRuntimeFactoryWithDefaultDataStore,
};
const DataRuntimeApi = {
    version: packageVersion_1.pkgVersion,
    DataObject: aqueduct_1.DataObject,
    DataObjectFactory: aqueduct_1.DataObjectFactory,
    TestFluidObjectFactory: test_utils_1.TestFluidObjectFactory,
    dds: {
        SharedCell: cell_1.SharedCell,
        SharedCounter: counter_1.SharedCounter,
        Ink: ink_1.Ink,
        SharedDirectory: map_1.SharedDirectory,
        SharedMap: map_1.SharedMap,
        SharedMatrix: matrix_1.SharedMatrix,
        ConsensusQueue: ordered_collection_1.ConsensusQueue,
        ConsensusRegisterCollection: register_collection_1.ConsensusRegisterCollection,
        SharedString: sequence_1.SharedString,
        SparseMatrix: sequence_deprecated_1.SparseMatrix,
    },
};
function getLoaderApi(baseVersion, requested) {
    const requestedStr = (0, versionUtils_1.getRequestedRange)(baseVersion, requested);
    // If the current version satisfies the range, use it.
    if (semver.satisfies(packageVersion_1.pkgVersion, requestedStr)) {
        return LoaderApi;
    }
    const { version, modulePath } = (0, versionUtils_1.checkInstalled)(requestedStr);
    return {
        version,
        Loader: (0, versionUtils_1.loadPackage)(modulePath, "@fluidframework/container-loader").Loader,
    };
}
exports.getLoaderApi = getLoaderApi;
function getContainerRuntimeApi(baseVersion, requested) {
    const requestedStr = (0, versionUtils_1.getRequestedRange)(baseVersion, requested);
    if (semver.satisfies(packageVersion_1.pkgVersion, requestedStr)) {
        return ContainerRuntimeApi;
    }
    const { version, modulePath } = (0, versionUtils_1.checkInstalled)(requestedStr);
    return {
        version,
        ContainerRuntime: (0, versionUtils_1.loadPackage)(modulePath, "@fluidframework/container-runtime")
            .ContainerRuntime,
        ContainerRuntimeFactoryWithDefaultDataStore: (0, versionUtils_1.loadPackage)(modulePath, "@fluidframework/aqueduct").ContainerRuntimeFactoryWithDefaultDataStore,
    };
}
exports.getContainerRuntimeApi = getContainerRuntimeApi;
function getDataRuntimeApi(baseVersion, requested) {
    const requestedStr = (0, versionUtils_1.getRequestedRange)(baseVersion, requested);
    if (semver.satisfies(packageVersion_1.pkgVersion, requestedStr)) {
        return DataRuntimeApi;
    }
    const { version, modulePath } = (0, versionUtils_1.checkInstalled)(requestedStr);
    return {
        version,
        DataObject: (0, versionUtils_1.loadPackage)(modulePath, "@fluidframework/aqueduct").DataObject,
        DataObjectFactory: (0, versionUtils_1.loadPackage)(modulePath, "@fluidframework/aqueduct").DataObjectFactory,
        TestFluidObjectFactory: (0, versionUtils_1.loadPackage)(modulePath, "@fluidframework/test-utils")
            .TestFluidObjectFactory,
        dds: {
            SharedCell: (0, versionUtils_1.loadPackage)(modulePath, "@fluidframework/cell").SharedCell,
            SharedCounter: (0, versionUtils_1.loadPackage)(modulePath, "@fluidframework/counter").SharedCounter,
            Ink: (0, versionUtils_1.loadPackage)(modulePath, "@fluidframework/ink").Ink,
            SharedDirectory: (0, versionUtils_1.loadPackage)(modulePath, "@fluidframework/map").SharedDirectory,
            SharedMap: (0, versionUtils_1.loadPackage)(modulePath, "@fluidframework/map").SharedMap,
            SharedMatrix: (0, versionUtils_1.loadPackage)(modulePath, "@fluidframework/matrix").SharedMatrix,
            ConsensusQueue: (0, versionUtils_1.loadPackage)(modulePath, "@fluidframework/ordered-collection")
                .ConsensusQueue,
            ConsensusRegisterCollection: (0, versionUtils_1.loadPackage)(modulePath, "@fluidframework/register-collection").ConsensusRegisterCollection,
            SharedString: (0, versionUtils_1.loadPackage)(modulePath, "@fluidframework/sequence").SharedString,
            SparseMatrix: (0, versionUtils_1.loadPackage)(modulePath, (0, versionUtils_1.versionHasMovedSparsedMatrix)(version)
                ? "@fluid-experimental/sequence-deprecated"
                : "@fluidframework/sequence").SparseMatrix,
        },
    };
}
exports.getDataRuntimeApi = getDataRuntimeApi;
function getDriverApi(baseVersion, requested) {
    const requestedStr = (0, versionUtils_1.getRequestedRange)(baseVersion, requested);
    // If the current version satisfies the range, use it.
    if (semver.satisfies(packageVersion_1.pkgVersion, requestedStr)) {
        return test_drivers_1.DriverApi;
    }
    const { version, modulePath } = (0, versionUtils_1.checkInstalled)(requestedStr);
    const localDriverApi = {
        version,
        LocalDocumentServiceFactory: (0, versionUtils_1.loadPackage)(modulePath, "@fluidframework/local-driver")
            .LocalDocumentServiceFactory,
        LocalResolver: (0, versionUtils_1.loadPackage)(modulePath, "@fluidframework/local-driver").LocalResolver,
        LocalDeltaConnectionServer: (0, versionUtils_1.loadPackage)(modulePath, "@fluidframework/server-local-server")
            .LocalDeltaConnectionServer,
        createLocalResolverCreateNewRequest: (0, versionUtils_1.loadPackage)(modulePath, "@fluidframework/local-driver")
            .createLocalResolverCreateNewRequest,
    };
    const odspDriverApi = {
        version,
        OdspDocumentServiceFactory: (0, versionUtils_1.loadPackage)(modulePath, "@fluidframework/odsp-driver")
            .OdspDocumentServiceFactory,
        OdspDriverUrlResolver: (0, versionUtils_1.loadPackage)(modulePath, "@fluidframework/odsp-driver")
            .OdspDriverUrlResolver,
        createOdspCreateContainerRequest: (0, versionUtils_1.loadPackage)(modulePath, "@fluidframework/odsp-driver")
            .createOdspCreateContainerRequest,
        createOdspUrl: (0, versionUtils_1.loadPackage)(modulePath, "@fluidframework/odsp-driver").createOdspUrl,
    };
    const routerliciousDriverApi = {
        version,
        modulePath,
        RouterliciousDocumentServiceFactory: (0, versionUtils_1.loadPackage)(modulePath, "@fluidframework/routerlicious-driver").RouterliciousDocumentServiceFactory,
    };
    return {
        LocalDriverApi: localDriverApi,
        OdspDriverApi: odspDriverApi,
        RouterliciousDriverApi: routerliciousDriverApi,
    };
}
exports.getDriverApi = getDriverApi;
//# sourceMappingURL=testApi.js.map